import { Column, Entity, JoinColumn, ManyToOne, OneToMany } from 'typeorm';
import { SceneDto, SceneIconDto } from '../dtos';
import { AbstractEntity } from '../../abstract/entities/abstract.entity';
import { SceneIconType } from '@app/common/constants/secne-icon-type.enum';
import { SceneDeviceEntity } from '../../scene-device/entities';
import { SpaceEntity } from '../../space/entities/space.entity';

// Define SceneIconEntity before SceneEntity
@Entity({ name: 'scene-icon' })
export class SceneIconEntity extends AbstractEntity<SceneIconDto> {
  @Column({
    nullable: true,
    type: 'text',
  })
  public icon: string;

  @Column({
    type: 'enum',
    enum: SceneIconType,
    default: SceneIconType.Other,
  })
  iconType: SceneIconType;

  @OneToMany(
    () => SceneEntity,
    (scenesIconEntity) => scenesIconEntity.sceneIcon,
  )
  scenesIconEntity: SceneEntity[];

  constructor(partial: Partial<SceneIconEntity>) {
    super();
    Object.assign(this, partial);
  }
}

@Entity({ name: 'scene' })
export class SceneEntity extends AbstractEntity<SceneDto> {
  @Column({
    type: 'uuid',
    default: () => 'gen_random_uuid()',
    nullable: false,
  })
  public uuid: string;

  @Column({
    nullable: false,
  })
  sceneTuyaUuid: string;

  @Column({
    nullable: false,
  })
  showInHomePage: boolean;

  @ManyToOne(() => SpaceEntity, (space) => space.scenes, {
    nullable: false,
    onDelete: 'CASCADE',
  })
  @JoinColumn({ name: 'space_uuid' })
  space: SpaceEntity;

  @Column({
    nullable: false,
    default: false,
  })
  public disabled: boolean;

  @ManyToOne(() => SceneIconEntity, (icon) => icon.scenesIconEntity, {
    nullable: false,
  })
  sceneIcon: SceneIconEntity;

  @OneToMany(() => SceneDeviceEntity, (sceneDevice) => sceneDevice.scene)
  sceneDevices: SceneDeviceEntity[];

  constructor(partial: Partial<SceneEntity>) {
    super();
    Object.assign(this, partial);
  }
}
