import { IsUUID, IsOptional, ValidateNested, IsArray } from 'class-validator';
import { Type } from 'class-transformer';
import { SpaceModelDto } from '../../space-model/dtos/space-model.dto';
import { ProductDto } from '../../product/dtos/product.dto';
import { NewTagDto } from '../../tag/dtos/tag.dto';
import { SpaceProductAllocationDto } from '../../space/dtos/space-product-allocation.dto';

export class SpaceModelProductAllocationDto {
  @IsUUID()
  uuid: string;

  @ValidateNested()
  @Type(() => SpaceModelDto)
  spaceModel: SpaceModelDto;

  @ValidateNested()
  @Type(() => ProductDto)
  product: ProductDto;

  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => NewTagDto)
  tags: NewTagDto[];

  @IsOptional()
  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => SpaceProductAllocationDto)
  inheritedSpaceAllocations?: SpaceProductAllocationDto[];
}
