import { AbstractEntity } from '@app/common/modules/abstract/entities/abstract.entity';
import { ProductEntity } from '@app/common/modules/product/entities/product.entity';
import { NewTagEntity } from '@app/common/modules/tag/entities/tag.entity';
import { Column, Entity, ManyToOne, Unique } from 'typeorm';
import { SubspaceModelProductAllocationDto } from '../../dtos/subspace-model/subspace-model-product-allocation.dto';
import { SubspaceModelEntity } from './subspace-model.entity';

@Entity({ name: 'subspace_model_product_allocation' })
@Unique(['subspaceModel', 'product', 'tag'])
export class SubspaceModelProductAllocationEntity extends AbstractEntity<SubspaceModelProductAllocationDto> {
  @Column({
    type: 'uuid',
    default: () => 'gen_random_uuid()',
    nullable: false,
  })
  public uuid: string;

  @ManyToOne(
    () => SubspaceModelEntity,
    (subspaceModel) => subspaceModel.productAllocations,
    {
      nullable: false,
      onDelete: 'CASCADE',
    },
  )
  public subspaceModel: SubspaceModelEntity;

  @ManyToOne(() => ProductEntity, { nullable: false, onDelete: 'CASCADE' })
  public product: ProductEntity;

  @ManyToOne(() => NewTagEntity, { nullable: true, onDelete: 'CASCADE' })
  public tag: NewTagEntity;

  constructor(partial: Partial<SubspaceModelProductAllocationEntity>) {
    super();
    Object.assign(this, partial);
  }
}
