import { PollutantType } from '@app/common/constants/pollutants.enum';
import { ApiProperty } from '@nestjs/swagger';
import { Matches, IsNotEmpty, IsString } from 'class-validator';

export class GetAqiDailyBySpaceDto {
  @ApiProperty({
    description: 'Month and year in format YYYY-MM',
    example: '2025-03',
    required: true,
  })
  @Matches(/^\d{4}-(0[1-9]|1[0-2])$/, {
    message: 'monthDate must be in YYYY-MM format',
  })
  @IsNotEmpty()
  monthDate: string;
}
export class GetAqiPollutantBySpaceDto {
  @ApiProperty({
    description: 'Pollutant Type',
    enum: PollutantType,
    example: PollutantType.AQI,
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public pollutantType: string;
  @ApiProperty({
    description: 'Month and year in format YYYY-MM',
    example: '2025-03',
    required: true,
  })
  @Matches(/^\d{4}-(0[1-9]|1[0-2])$/, {
    message: 'monthDate must be in YYYY-MM format',
  })
  @IsNotEmpty()
  monthDate: string;
}
