import { BaseResponseDto } from '@app/common/dto/base.response.dto';
import { SuccessResponseDto } from '@app/common/dto/success.response.dto';
import { ProductRepository } from '@app/common/modules/product/repositories';
import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { AddProductDto } from '../dtos';

@Injectable()
export class ProductService {
  constructor(private readonly productRepository: ProductRepository) {}

  async addNewProductType(
    addProductDto: AddProductDto,
  ): Promise<BaseResponseDto> {
    try {
      const {
        tuyaCategoryName,
        tuyaProductId,
        syncrowProductType,
        syncrowProductName,
      } = addProductDto;
      const product = await this.productRepository.save({
        catName: tuyaCategoryName,
        prodId: tuyaProductId,
        prodType: syncrowProductType,
        name: syncrowProductName,
      });
      return new SuccessResponseDto({
        data: product,
        message: 'Successfully added new product type',
      });
    } catch (error) {
      throw new HttpException(
        `Error adding new product type: ${error.message}`,
        HttpStatus.INTERNAL_SERVER_ERROR,
      );
    }
  }
  async list(): Promise<BaseResponseDto> {
    const products = await this.productRepository.find();

    if (!products) {
      throw new HttpException(
        `No products found in the system`,
        HttpStatus.NOT_FOUND,
      );
    }
    return new SuccessResponseDto({
      data: products,
      message: 'List of products retrieved successfully',
    });
  }

  async findOne(productUuid: string): Promise<BaseResponseDto> {
    const product = await this.productRepository.findOne({
      where: {
        uuid: productUuid,
      },
    });
    if (!product) {
      throw new HttpException(
        `No product with ${productUuid} found in the system`,
        HttpStatus.NOT_FOUND,
      );
    }

    return new SuccessResponseDto({
      data: product,
      message: 'Successfully retrieved product',
    });
  }
}
