import { ControllerRoute } from '@app/common/constants/controller-route';
import { BaseResponseDto } from '@app/common/dto/base.response.dto';
import { Controller, Get, Param, Query, UseGuards } from '@nestjs/common';
import { ApiBearerAuth, ApiOperation, ApiTags } from '@nestjs/swagger';
import { SpaceSceneService } from '../services';
import { GetSceneDto } from '../../scene/dtos';
import { GetSpaceParam } from '../dtos';
import { PermissionsGuard } from 'src/guards/permissions.guard';
import { Permissions } from 'src/decorators/permissions.decorator';

@ApiTags('Space Module')
@Controller({
  version: '1',
  path: ControllerRoute.SPACE_SCENE.ROUTE,
})
export class SpaceSceneController {
  constructor(private readonly sceneService: SpaceSceneService) {}

  @ApiBearerAuth()
  @UseGuards(PermissionsGuard)
  @Permissions('SCENES_VIEW')
  @ApiOperation({
    summary:
      ControllerRoute.SPACE_SCENE.ACTIONS.GET_TAP_TO_RUN_SCENE_BY_SPACE_SUMMARY,
    description:
      ControllerRoute.SPACE_SCENE.ACTIONS
        .GET_TAP_TO_RUN_SCENE_BY_SPACE_DESCRIPTION,
  })
  @Get()
  async getTapToRunSceneByUnit(
    @Param() params: GetSpaceParam,
    @Query() inHomePage: GetSceneDto,
  ): Promise<BaseResponseDto> {
    return await this.sceneService.getScenes(params, inHomePage);
  }
}
