import { Injectable } from '@nestjs/common';
import { TagService } from 'src/tags/services';
import {
  AllocationsOwnerType,
  CreateAllocationsDto,
} from '../../dtos/create-allocations.dto';
import { SpaceProductAllocationService } from '../space-product-allocation.service';
import { SubspaceProductAllocationService } from '../subspace/subspace-product-allocation.service';

@Injectable()
export class ProductAllocationService {
  constructor(
    private readonly tagService: TagService,
    private readonly spaceProductAllocationService: SpaceProductAllocationService,
    private readonly subSpaceProductAllocationService: SubspaceProductAllocationService,
  ) {}

  async createAllocations(dto: CreateAllocationsDto): Promise<void> {
    const { projectUuid, queryRunner, tags, type } = dto;

    const allocationsData = await this.tagService.processTags(
      tags,
      projectUuid,
      queryRunner,
    );

    // Create a mapping of created tags by UUID and name for quick lookup
    const createdTagsByUUID = new Map(allocationsData.map((t) => [t.uuid, t]));
    const createdTagsByName = new Map(allocationsData.map((t) => [t.name, t]));

    // Create the product-tag mapping based on the processed tags
    const productTagMapping = tags.map(({ uuid, name, productUuid }) => {
      const inputTag = uuid
        ? createdTagsByUUID.get(uuid)
        : createdTagsByName.get(name);
      return {
        tag: inputTag?.uuid,
        product: productUuid,
      };
    });

    switch (type) {
      case AllocationsOwnerType.SPACE: {
        // todo: take to consideration original method implementation
        await this.spaceProductAllocationService.createProductAllocations(
          dto.space,
          productTagMapping,
          queryRunner,
        );
        break;
      }
      case AllocationsOwnerType.SUBSPACE: {
        await this.subSpaceProductAllocationService.createProductAllocations(
          dto.subspace,
          productTagMapping,
          queryRunner,
        );
        break;
      }
    }
  }
}
