import { Body, Controller, Get, Param, Post, UseGuards } from '@nestjs/common';
import { TagService } from '../services/tags.service';
import { ApiTags, ApiBearerAuth, ApiOperation } from '@nestjs/swagger';
import { JwtAuthGuard } from '../../../libs/common/src/guards/jwt.auth.guard';
import { EnableDisableStatusEnum } from '@app/common/constants/days.enum';
import { ControllerRoute } from '@app/common/constants/controller-route';
import { BaseResponseDto } from '@app/common/dto/base.response.dto';
import { CreateTagDto } from '../dtos/tags.dto';
import { ProjectParam } from '@app/common/dto/project-param.dto';

@ApiTags('Tag Module')
@Controller({
  version: EnableDisableStatusEnum.ENABLED,
  path: ControllerRoute.TAG.ROUTE,
})
export class TagController {
  constructor(private readonly tagService: TagService) {}

  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Post()
  @ApiOperation({
    summary: ControllerRoute.TAG.ACTIONS.CREATE_TAG_SUMMARY,
    description: ControllerRoute.TAG.ACTIONS.CREATE_TAG_DESCRIPTION,
  })
  async createTag(
    @Body() dto: CreateTagDto,
    @Param() param: ProjectParam,
  ): Promise<BaseResponseDto> {
    return this.tagService.createTag(dto, param);
  }

  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Get()
  @ApiOperation({
    summary: ControllerRoute.TAG.ACTIONS.GET_TAGS_BY_PROJECT_SUMMARY,
    description: ControllerRoute.TAG.ACTIONS.GET_TAGS_BY_PROJECT_DESCRIPTION,
  })
  async getTagsByProject(
    @Param() params: ProjectParam,
  ): Promise<BaseResponseDto> {
    return this.tagService.getTagsByProjectUuid(params);
  }
}
